==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/SLOHistoryResponseErrorWithType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.Objects;

/** An object describing the error with error type and error message. */
@JsonPropertyOrder({
  SLOHistoryResponseErrorWithType.JSON_PROPERTY_ERROR_MESSAGE,
  SLOHistoryResponseErrorWithType.JSON_PROPERTY_ERROR_TYPE
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class SLOHistoryResponseErrorWithType {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_ERROR_MESSAGE = "error_message";
  private String errorMessage;

  public static final String JSON_PROPERTY_ERROR_TYPE = "error_type";
  private String errorType;

  public SLOHistoryResponseErrorWithType() {}

  @JsonCreator
  public SLOHistoryResponseErrorWithType(
      @JsonProperty(required = true, value = JSON_PROPERTY_ERROR_MESSAGE) String errorMessage,
      @JsonProperty(required = true, value = JSON_PROPERTY_ERROR_TYPE) String errorType) {
    this.errorMessage = errorMessage;
    this.errorType = errorType;
  }

  public SLOHistoryResponseErrorWithType errorMessage(String errorMessage) {
    this.errorMessage = errorMessage;
    return this;
  }

  /**
   * A message with more details about the error.
   *
   * @return errorMessage
   */
  @JsonProperty(JSON_PROPERTY_ERROR_MESSAGE)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public String getErrorMessage() {
    return errorMessage;
  }

  public void setErrorMessage(String errorMessage) {
    this.errorMessage = errorMessage;
  }

  public SLOHistoryResponseErrorWithType errorType(String errorType) {
    this.errorType = errorType;
    return this;
  }

  /**
   * Type of the error.
   *
   * @return errorType
   */
  @JsonProperty(JSON_PROPERTY_ERROR_TYPE)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public String getErrorType() {
    return errorType;
  }

  public void setErrorType(String errorType) {
    this.errorType = errorType;
  }

  /** Return true if this SLOHistoryResponseErrorWithType object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SLOHistoryResponseErrorWithType sloHistoryResponseErrorWithType =
        (SLOHistoryResponseErrorWithType) o;
    return Objects.equals(this.errorMessage, sloHistoryResponseErrorWithType.errorMessage)
        && Objects.equals(this.errorType, sloHistoryResponseErrorWithType.errorType);
  }

  @Override
  public int hashCode() {
    return Objects.hash(errorMessage, errorType);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SLOHistoryResponseErrorWithType {\n");
    sb.append("    errorMessage: ").append(toIndentedString(errorMessage)).append("\n");
    sb.append("    errorType: ").append(toIndentedString(errorType)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> datadog-api-client-2.24.0-sources.jar: com/datadog/api/client/v1/model/SLOHistoryResponseErrorWithType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/** An object describing the error with error type and error message. */
@JsonPropertyOrder({
  SLOHistoryResponseErrorWithType.JSON_PROPERTY_ERROR_MESSAGE,
  SLOHistoryResponseErrorWithType.JSON_PROPERTY_ERROR_TYPE
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class SLOHistoryResponseErrorWithType {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_ERROR_MESSAGE = "error_message";
  private String errorMessage;

  public static final String JSON_PROPERTY_ERROR_TYPE = "error_type";
  private String errorType;

  public SLOHistoryResponseErrorWithType() {}

  @JsonCreator
  public SLOHistoryResponseErrorWithType(
      @JsonProperty(required = true, value = JSON_PROPERTY_ERROR_MESSAGE) String errorMessage,
      @JsonProperty(required = true, value = JSON_PROPERTY_ERROR_TYPE) String errorType) {
    this.errorMessage = errorMessage;
    this.errorType = errorType;
  }

  public SLOHistoryResponseErrorWithType errorMessage(String errorMessage) {
    this.errorMessage = errorMessage;
    return this;
  }

  /**
   * A message with more details about the error.
   *
   * @return errorMessage
   */
  @JsonProperty(JSON_PROPERTY_ERROR_MESSAGE)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public String getErrorMessage() {
    return errorMessage;
  }

  public void setErrorMessage(String errorMessage) {
    this.errorMessage = errorMessage;
  }

  public SLOHistoryResponseErrorWithType errorType(String errorType) {
    this.errorType = errorType;
    return this;
  }

  /**
   * Type of the error.
   *
   * @return errorType
   */
  @JsonProperty(JSON_PROPERTY_ERROR_TYPE)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public String getErrorType() {
    return errorType;
  }

  public void setErrorType(String errorType) {
    this.errorType = errorType;
  }

  /**
   * A container for additional, undeclared properties. This is a holder for any undeclared
   * properties as specified with the 'additionalProperties' keyword in the OAS document.
   */
  private Map<String, Object> additionalProperties;

  /**
   * Set the additional (undeclared) property with the specified name and value. If the property
   * does not already exist, create it otherwise replace it.
   *
   * @param key The arbitrary key to set
   * @param value The associated value
   * @return SLOHistoryResponseErrorWithType
   */
  @JsonAnySetter
  public SLOHistoryResponseErrorWithType putAdditionalProperty(String key, Object value) {
    if (this.additionalProperties == null) {
      this.additionalProperties = new HashMap<String, Object>();
    }
    this.additionalProperties.put(key, value);
    return this;
  }

  /**
   * Return the additional (undeclared) property.
   *
   * @return The additional properties
   */
  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * Return the additional (undeclared) property with the specified name.
   *
   * @param key The arbitrary key to get
   * @return The specific additional property for the given key
   */
  public Object getAdditionalProperty(String key) {
    if (this.additionalProperties == null) {
      return null;
    }
    return this.additionalProperties.get(key);
  }

  /** Return true if this SLOHistoryResponseErrorWithType object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SLOHistoryResponseErrorWithType sloHistoryResponseErrorWithType =
        (SLOHistoryResponseErrorWithType) o;
    return Objects.equals(this.errorMessage, sloHistoryResponseErrorWithType.errorMessage)
        && Objects.equals(this.errorType, sloHistoryResponseErrorWithType.errorType)
        && Objects.equals(
            this.additionalProperties, sloHistoryResponseErrorWithType.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(errorMessage, errorType, additionalProperties);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SLOHistoryResponseErrorWithType {\n");
    sb.append("    errorMessage: ").append(toIndentedString(errorMessage)).append("\n");
    sb.append("    errorType: ").append(toIndentedString(errorType)).append("\n");
    sb.append("    additionalProperties: ")
        .append(toIndentedString(additionalProperties))
        .append("\n");
    sb.append('}');
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
